@@ -14,7 +14,6 @@ from .auth_response_user import AuthResponseUser
 from .available_extension import AvailableExtension
 from .available_extensions_response import AvailableExtensionsResponse
 from .backup_create_request import BackupCreateRequest
-from .backup_export_request import BackupExportRequest
 from .backup_list_response import BackupListResponse
 from .backup_response import BackupResponse
 from .backup_restore_request import BackupRestoreRequest
@@ -34,12 +33,16 @@ from .connection_provider_info_provider import ConnectionProviderInfoProvider
 from .connection_response import ConnectionResponse
 from .connection_response_metadata import ConnectionResponseMetadata
 from .connection_response_provider import ConnectionResponseProvider
+from .copy_response import CopyResponse
+from .copy_response_error_details_type_0 import CopyResponseErrorDetailsType0
+from .copy_response_status import CopyResponseStatus
 from .create_api_key_request import CreateAPIKeyRequest
 from .create_api_key_response import CreateAPIKeyResponse
 from .create_connection_request import CreateConnectionRequest
 from .create_connection_request_provider import CreateConnectionRequestProvider
 from .create_graph_request import CreateGraphRequest
-from .credit_check_request import CreditCheckRequest
+from .create_subgraph_request import CreateSubgraphRequest
+from .create_subgraph_request_metadata_type_0 import CreateSubgraphRequestMetadataType0
 from .credit_summary import CreditSummary
 from .credit_summary_response import CreditSummaryResponse
 from .credits_summary_response import CreditsSummaryResponse
@@ -54,8 +57,12 @@ from .custom_schema_definition_relationships_item import (
 )
 from .cypher_query_request import CypherQueryRequest
 from .cypher_query_request_parameters_type_0 import CypherQueryRequestParametersType0
+from .data_frame_copy_request import DataFrameCopyRequest
+from .data_frame_copy_request_format import DataFrameCopyRequestFormat
 from .database_health_response import DatabaseHealthResponse
 from .database_info_response import DatabaseInfoResponse
+from .delete_subgraph_request import DeleteSubgraphRequest
+from .delete_subgraph_response import DeleteSubgraphResponse
 from .detailed_transactions_response import DetailedTransactionsResponse
 from .detailed_transactions_response_date_range import (
   DetailedTransactionsResponseDateRange,
@@ -86,6 +93,9 @@ from .get_current_graph_bill_response_getcurrentgraphbill import (
 from .get_graph_billing_history_response_getgraphbillinghistory import (
   GetGraphBillingHistoryResponseGetgraphbillinghistory,
 )
+from .get_graph_limits_response_getgraphlimits import (
+  GetGraphLimitsResponseGetgraphlimits,
+)
 from .get_graph_monthly_bill_response_getgraphmonthlybill import (
   GetGraphMonthlyBillResponseGetgraphmonthlybill,
 )
@@ -121,9 +131,6 @@ from .health_status import HealthStatus
 from .health_status_details_type_0 import HealthStatusDetailsType0
 from .http_validation_error import HTTPValidationError
 from .initial_entity_data import InitialEntityData
-from .kuzu_backup_health_response_kuzubackuphealth import (
-  KuzuBackupHealthResponseKuzubackuphealth,
-)
 from .link_token_request import LinkTokenRequest
 from .link_token_request_options_type_0 import LinkTokenRequestOptionsType0
 from .link_token_request_provider_type_0 import LinkTokenRequestProviderType0
@@ -131,6 +138,7 @@ from .list_connections_provider_type_0 import ListConnectionsProviderType0
 from .list_schema_extensions_response_listschemaextensions import (
   ListSchemaExtensionsResponseListschemaextensions,
 )
+from .list_subgraphs_response import ListSubgraphsResponse
 from .login_request import LoginRequest
 from .logout_user_response_logoutuser import LogoutUserResponseLogoutuser
 from .mcp_tool_call import MCPToolCall
@@ -161,6 +169,9 @@ from .repository_credits_response import RepositoryCreditsResponse
 from .repository_plan import RepositoryPlan
 from .repository_type import RepositoryType
 from .response_mode import ResponseMode
+from .s3_copy_request import S3CopyRequest
+from .s3_copy_request_file_format import S3CopyRequestFileFormat
+from .s3_copy_request_s3_url_style_type_0 import S3CopyRequestS3UrlStyleType0
 from .schema_export_response import SchemaExportResponse
 from .schema_export_response_data_stats_type_0 import SchemaExportResponseDataStatsType0
 from .schema_export_response_schema_definition_type_0 import (
@@ -182,6 +193,11 @@ from .sso_exchange_response import SSOExchangeResponse
 from .sso_login_request import SSOLoginRequest
 from .sso_token_response import SSOTokenResponse
 from .storage_limit_response import StorageLimitResponse
+from .subgraph_quota_response import SubgraphQuotaResponse
+from .subgraph_response import SubgraphResponse
+from .subgraph_response_metadata_type_0 import SubgraphResponseMetadataType0
+from .subgraph_summary import SubgraphSummary
+from .subgraph_type import SubgraphType
 from .subscription_info import SubscriptionInfo
 from .subscription_info_metadata import SubscriptionInfoMetadata
 from .subscription_request import SubscriptionRequest
@@ -200,7 +216,9 @@ from .transaction_summary_response import TransactionSummaryResponse
 from .update_api_key_request import UpdateAPIKeyRequest
 from .update_password_request import UpdatePasswordRequest
 from .update_user_request import UpdateUserRequest
-from .upgrade_subscription_request import UpgradeSubscriptionRequest
+from .url_copy_request import URLCopyRequest
+from .url_copy_request_file_format import URLCopyRequestFileFormat
+from .url_copy_request_headers_type_0 import URLCopyRequestHeadersType0
 from .user_analytics_response import UserAnalyticsResponse
 from .user_analytics_response_api_usage import UserAnalyticsResponseApiUsage
 from .user_analytics_response_graph_usage import UserAnalyticsResponseGraphUsage
@@ -237,7 +255,6 @@ __all__ = (
   "AvailableExtension",
   "AvailableExtensionsResponse",
   "BackupCreateRequest",
-  "BackupExportRequest",
   "BackupListResponse",
   "BackupResponse",
   "BackupRestoreRequest",
@@ -253,12 +270,16 @@ __all__ = (
   "ConnectionResponse",
   "ConnectionResponseMetadata",
   "ConnectionResponseProvider",
+  "CopyResponse",
+  "CopyResponseErrorDetailsType0",
+  "CopyResponseStatus",
   "CreateAPIKeyRequest",
   "CreateAPIKeyResponse",
   "CreateConnectionRequest",
   "CreateConnectionRequestProvider",
   "CreateGraphRequest",
-  "CreditCheckRequest",
+  "CreateSubgraphRequest",
+  "CreateSubgraphRequestMetadataType0",
   "CreditsSummaryResponse",
   "CreditsSummaryResponseCreditsByAddonItem",
   "CreditSummary",
@@ -271,6 +292,10 @@ __all__ = (
   "CypherQueryRequestParametersType0",
   "DatabaseHealthResponse",
   "DatabaseInfoResponse",
+  "DataFrameCopyRequest",
+  "DataFrameCopyRequestFormat",
+  "DeleteSubgraphRequest",
+  "DeleteSubgraphResponse",
   "DetailedTransactionsResponse",
   "DetailedTransactionsResponseDateRange",
   "DetailedTransactionsResponseSummary",
@@ -285,6 +310,7 @@ __all__ = (
   "GetCurrentAuthUserResponseGetcurrentauthuser",
   "GetCurrentGraphBillResponseGetcurrentgraphbill",
   "GetGraphBillingHistoryResponseGetgraphbillinghistory",
+  "GetGraphLimitsResponseGetgraphlimits",
   "GetGraphMonthlyBillResponseGetgraphmonthlybill",
   "GetGraphSchemaInfoResponseGetgraphschemainfo",
   "GetGraphUsageDetailsResponseGetgraphusagedetails",
@@ -306,12 +332,12 @@ __all__ = (
   "HealthStatusDetailsType0",
   "HTTPValidationError",
   "InitialEntityData",
-  "KuzuBackupHealthResponseKuzubackuphealth",
   "LinkTokenRequest",
   "LinkTokenRequestOptionsType0",
   "LinkTokenRequestProviderType0",
   "ListConnectionsProviderType0",
   "ListSchemaExtensionsResponseListschemaextensions",
+  "ListSubgraphsResponse",
   "LoginRequest",
   "LogoutUserResponseLogoutuser",
   "MCPToolCall",
@@ -336,6 +362,9 @@ __all__ = (
   "RepositoryPlan",
   "RepositoryType",
   "ResponseMode",
+  "S3CopyRequest",
+  "S3CopyRequestFileFormat",
+  "S3CopyRequestS3UrlStyleType0",
   "SchemaExportResponse",
   "SchemaExportResponseDataStatsType0",
   "SchemaExportResponseSchemaDefinitionType0",
@@ -351,6 +380,11 @@ __all__ = (
   "SSOLoginRequest",
   "SSOTokenResponse",
   "StorageLimitResponse",
+  "SubgraphQuotaResponse",
+  "SubgraphResponse",
+  "SubgraphResponseMetadataType0",
+  "SubgraphSummary",
+  "SubgraphType",
   "SubscriptionInfo",
   "SubscriptionInfoMetadata",
   "SubscriptionRequest",
@@ -365,7 +399,9 @@ __all__ = (
   "UpdateAPIKeyRequest",
   "UpdatePasswordRequest",
   "UpdateUserRequest",
-  "UpgradeSubscriptionRequest",
+  "URLCopyRequest",
+  "URLCopyRequestFileFormat",
+  "URLCopyRequestHeadersType0",
   "UserAnalyticsResponse",
   "UserAnalyticsResponseApiUsage",
   "UserAnalyticsResponseGraphUsage",
